==============================================
  #### AGRICULTURE -CORRELATION MS ANALYSES #####
===============================================


# DATA PREPARATION:

library(ggplot2)
landp1 <- read.csv("C://Users/Chris/Desktop/agri schisto ms/EHP submission/landuse_stanford_and_our7village_weightedmeans_1_13.csv")
#this file needs to be sorted by column reinfection largest to smallest, so that all NAs for
#reinfection are at the top (rows 2-8), which we will drop for the correlation test:
landp1.3=landp1[-c(2:8), ] 
landp1.3$prevbase=landp1.3$prevalence_baseline/100
landp1.3$prevre1=landp1.3$prevalence_reinfection_2017/100
landp1.3$prevre2=landp1.3$prevalence_reinfection2018/100


###PLOT REINFECTION 1 to BASELINE:###  Fig. S1A

setwd("C:/Users/Chris/Desktop/")
tiff(file="plot1.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
ggplot(landp1.3, aes(x=prevbase, y=prevre1)) + geom_point(size=2)+
  geom_smooth(method=lm,
              color="black", fill="gray")+
  labs(title="",
       x="Baseline prevalence 2016", y = "Re-infection prevalence 2017")+
  theme_classic(base_size = 16)  + scale_y_continuous(
    labels = scales::number_format(accuracy = 0.1,
                                   decimal.mark = '.')) 
dev.off()

### PLOT REINFECTION 2 to BASELINE:###  Fig. S1B

setwd("C:/Users/Chris/Desktop/")
tiff(file="plot2.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
ggplot(landp1.3, aes(x=prevbase, y=prevre2)) + geom_point(size=2)+
  geom_smooth(method=lm,
              color="black", fill="gray")+
  labs(title="",
       x="Baseline prevalence 2016", y = "Re-infection prevalence 2018")+
  theme_classic(base_size = 16)  + scale_y_continuous(
    labels = scales::number_format(accuracy = 0.1,
                                   decimal.mark = '.')) 
dev.off()

### CORRELATIONS:
cor.test(landp1.3$prevbase,landp1.3$prevre1,method="spearman")
cor.test(landp1.3$prevbase,landp1.3$prevre2,method="spearman")
cor.test(landp1.3$ha.total.of.referenced.fields,landp1.3$TotalFert,method="spearman")
landp1.3$logtotalfert=log(landp1.3$TotalFert+1)
cor.test(landp1.3$logtotalfert,landp1.3$avgFloatFM1FM4,method="spearman")

cor.test(landp1.3$ha.total.of.referenced.fields,landp1.3$population,method="spearman")
S = 726, p-value = 0.8051
alternative hypothesis: true rho is not equal to 0
sample estimates:
  rho 
-0.06764706 


###PLOT HUMAN INFECTION VS. TOTAL CROPS 0.5km:

#BASELINE INFECTION TO TOTAL CROPS 0.5km###  Fig. 2A
landp1$baseprev=landp1$prevalence_baseline/100
setwd("C:/Users/Chris/Desktop/")
tiff(file="plot3.3.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)

landp1$Year.baseline=as.factor(landp1$Year.baseline)
ggplot(landp1, aes(x=sqkmtotalcrop0.5km, y=baseprev)) + geom_point(size=2,mapping=aes(shape=Year.baseline,stroke=1.5))+
  geom_smooth(method=lm,
              color="black", fill="gray")+
  scale_shape_manual(values=c(1,2))+
  labs(title="",
       x="Total crop cover in 0.5km", y = "Baseline human prevalence")+
  theme_classic(base_size = 16) + scale_y_continuous(
    labels = scales::number_format(accuracy = 0.1,
                                   decimal.mark = '.')) +theme(legend.position='none')  
dev.off()

#REINFECTION TO TOTAL FIELD AREA (HA) ### Fig. 2B
setwd("C:/Users/Chris/Desktop/")
tiff(file="plot4.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
ggplot(landp1, aes(x=ha.total.of.referenced.fields, y=baseprev)) + geom_point(size=2,stroke=1.5)+
  geom_smooth(method=lm,
              color="black", fill="gray")+
  scale_shape_manual(values=c(1))+
  labs(title="",
       x="Total field area (ha)", y = "Baseline human prevalence")+
  theme_classic(base_size = 16) + scale_y_continuous(
    labels = scales::number_format(accuracy = 0.1,
                                   decimal.mark = '.'))   
dev.off()

### CROP FIELD AREA (HA) VS. FERTILIZER USE:   Fig. 3A
setwd("C:/Users/Chris/Desktop/")
tiff(file="plot5.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
ggplot(landp1, aes(x=ha.total.of.referenced.fields, y=TotalFert)) + geom_point(size=2)+
  geom_smooth(method=lm,
              color="black", fill="gray")+
  labs(title="",
       x="Total field area (ha)", y = "Total fertilizer use (ha)")+
  theme_classic(base_size = 16) 
dev.off()

### AQUATIC VEG AREA VS. FERTILIZER USE:   Fig. 3B
landp1$logtotalfert=log(landp1$TotalFert+1)
setwd("C:/Users/Chris/Desktop/")
tiff(file="plotFloatvFert.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
ggplot(landp1, aes(x=logtotalfert, y=avgFloatFM1FM4)) + geom_point(size=2)+
  geom_smooth(method=lm,
              color="black", fill="gray")+
  labs(title="",
       x="Ln-transformed total fertilizer", y = "Mean floating vegetation area (m2)")+
  theme_classic(base_size = 16)+scale_y_continuous(limits = c(-200, 3500))
dev.off()



###########################################################
##########################HUMAN INFECTION #################
###########################################################


#Regression of human infection using all 23 villages:
landp1 <- read.csv("C://Users/Chris/Desktop/latest agri edits/landuse_stanford_and_our7village_weightedmeans_1_13.csv")
landp1 <- read.csv("C://Users/Chris/Desktop/agri schisto ms/EHP submission/landuse_stanford_and_our7village_weightedmeans_1_13.csv")

landp1$accessArea=landp1$Sum.of.area_FM3_17


#Examine correlations prior to regression:
#install.packages("PerformanceAnalytics")
library(PerformanceAnalytics)  
data1=landp1[,c(3:4,18,297)]
chart.Correlation(data1,histogram=TRUE,pch=19)
#village population and rural area correated. Going to drop rural from analyses to keep simpler the model selection
setwd("C:/Users/Chris/Desktop/")
tiff(file="Corr1.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
chart.Correlation(data1,histogram=TRUE,pch=19)
dev.off()


#NEGATIVE BINOMIAL REGRESSIONS OF VILLAGE ATTRIBUTES

#Preliminary examination of which scales best:
library(AICcmodavg)
library(MASS)
m0.5km=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+ sqkmwater0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
m1km=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+ sqkmwater1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
m2km=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+sqkmwater2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

models_1<-list(m0.5km,m1km,m2km)
Modnames_1 <- c('0.5km','1km','2km') 
aictab(cand.set = models_1, modnames = Modnames_1, sort = TRUE)

Model selection based on AICc:
  
  K   AICc Delta_AICc AICcWt Cum.Wt     LL
0.5km 5 202.94       0.00   0.82   0.82 -94.70
2km   5 207.00       4.06   0.11   0.93 -96.73
1km   5 207.85       4.91   0.07   1.00 -97.16


#0.5km is best, can we check this all at once as in code below for Table 2?
library(AICcmodavg)
library(MASS)
mm1=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+ sqkmwater0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm2=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm3=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+sqkmwater0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm4=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm5=glm.nb(infectedkids_baseline~ sqkmwater0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm6=glm.nb(infectedkids_baseline~ sqkmwater0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm7=glm.nb(infectedkids_baseline~ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm8=glm.nb(infectedkids_baseline~ sqkmwater0.5km+Sum.of.area_FM3_17+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm9=glm.nb(infectedkids_baseline~ population +offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm10=glm.nb(infectedkids_baseline~ population +Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm11=glm.nb(infectedkids_baseline~ population +Sum.of.area_FM3_17+sqkmwater0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm12=glm.nb(infectedkids_baseline~ Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mm13=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm14=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm15=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm16=glm.nb(infectedkids_baseline~ sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mm1.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+ sqkmwater1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm2.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm3.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+sqkmwater1km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm4.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm5.1=glm.nb(infectedkids_baseline~ sqkmwater1km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm6.1=glm.nb(infectedkids_baseline~ sqkmwater1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm7.1=glm.nb(infectedkids_baseline~ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm8.1=glm.nb(infectedkids_baseline~ sqkmwater1km+Sum.of.area_FM3_17+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mm13.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm14.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm15.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+ sqkmwater1km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm16.1=glm.nb(infectedkids_baseline~ sqkmtotalcrop1km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mm1.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+ sqkmwater2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm2.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm3.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+sqkmwater2km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm4.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm5.2=glm.nb(infectedkids_baseline~ sqkmwater2km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm6.2=glm.nb(infectedkids_baseline~ sqkmwater2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm7.2=glm.nb(infectedkids_baseline~ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm8.2=glm.nb(infectedkids_baseline~ sqkmwater2km+Sum.of.area_FM3_17+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mm13.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm14.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm15.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+ sqkmwater2km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mm16.2=glm.nb(infectedkids_baseline~ sqkmtotalcrop2km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

models_big<-list(mm1,mm2,mm3,mm4,mm5,mm6,mm7,mm8,mm9,mm10,mm11,mm12,mm13,mm14,mm15,mm16,mm1.1,mm2.1,mm3.1,mm4.1,mm5.1,mm6.1,mm7.1,mm8.1,mm13.1,mm14.1,mm15.1,mm16.1,mm1.2,mm2.2,mm3.2,mm4.2,mm5.2,mm6.2,mm7.2,mm8.2,mm13.2,mm14.2,mm15.2,mm16.2)
Modnames_big <- c('sqkmtotalcrop0.5km+ sqkmwater0.5km+population',
              'sqkmtotalcrop0.5km+population',
              'sqkmtotalcrop0.5km+sqkmwater0.5km',
              'sqkmtotalcrop0.5km',
              'sqkmwater0.5km',
              'sqkmwater0.5km+population',
              'sqkmwater0.5km+Sum.of.area_FM3_17',
              'sqkmwater0.5km+Sum.of.area_FM3_17+population',
              'population',
              'population +Sum.of.area_FM3_17',
              'population +Sum.of.area_FM3_17+sqkmwater0.5km',
              'Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17',
              'sqkmtotalcrop1km+ sqkmwater1km+population',
              'sqkmtotalcrop1km+population',
              'sqkmtotalcrop1km+sqkmwater1km',
              'sqkmtotalcrop1km',
              'sqkmwater1km',
              'sqkmwater1km+population',
              'sqkmwater1km+Sum.of.area_FM3_17',
              'sqkmwater1km+Sum.of.area_FM3_17+population',
              'sqkmtotalcrop1km+Sum.of.area_FM3_17',
              'sqkmtotalcrop1km+ sqkmwater1km+Sum.of.area_FM3_17',
              'sqkmtotalcrop1km+ sqkmwater1km+population+Sum.of.area_FM3_17',
              'sqkmtotalcrop1km+population+Sum.of.area_FM3_17',
              'sqkmtotalcrop2km+ sqkmwater2km+population',
              'sqkmtotalcrop2km+population',
              'sqkmtotalcrop2km+sqkmwater2km',
              'sqkmtotalcrop2km',
              'sqkmwater2km',
              'sqkmwater2km+population',
              'sqkmwater2km+Sum.of.area_FM3_17',
              'sqkmwater2km+Sum.of.area_FM3_17+population',
              'sqkmtotalcrop2km+Sum.of.area_FM3_17',
              'sqkmtotalcrop2km+ sqkmwater2km+Sum.of.area_FM3_17',
              'sqkmtotalcrop2km+ sqkmwater2km+population+Sum.of.area_FM3_17',
              'sqkmtotalcrop2km+population+Sum.of.area_FM3_17') 
aictab(cand.set = models_big, modnames = Modnames_big, sort = TRUE)

Model selection based on AICc:
  
                                                                 K   AICc Delta_AICc AICcWt Cum.Wt     LL
sqkmtotalcrop0.5km                                               3 198.51       0.00   0.21   0.21 -95.62
sqkmtotalcrop0.5km+sqkmwater0.5km                                4 199.73       1.22   0.11   0.32 -94.75
Sum.of.area_FM3_17                                               3 200.75       2.24   0.07   0.38 -96.74
sqkmwater2km+Sum.of.area_FM3_17                                  4 201.30       2.80   0.05   0.43 -95.54
sqkmtotalcrop0.5km+Sum.of.area_FM3_17                            4 201.33       2.83   0.05   0.48 -95.55
sqkmtotalcrop0.5km+population                                    4 201.36       2.85   0.05   0.53 -95.57
sqkmwater2km                                                     3 201.43       2.92   0.05   0.58 -97.08
sqkmwater0.5km                                                   3 202.24       3.74   0.03   0.61 -97.49
sqkmtotalcrop2km                                                 3 202.36       3.85   0.03   0.64 -97.55
sqkmtotalcrop1km                                                 3 202.36       3.86   0.03   0.67 -97.55
sqkmwater1km                                                     3 202.66       4.15   0.03   0.70 -97.70
sqkmwater1km+Sum.of.area_FM3_17                                  4 202.74       4.23   0.02   0.72 -96.26
population                                                       3 202.88       4.37   0.02   0.75 -97.81
sqkmtotalcrop2km+Sum.of.area_FM3_17                              4 202.92       4.41   0.02   0.77 -96.35
sqkmtotalcrop0.5km+ sqkmwater0.5km+population                    5 202.94       4.43   0.02   0.79 -94.70
sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17            5 203.03       4.52   0.02   0.81 -94.75
sqkmwater0.5km+Sum.of.area_FM3_17                                4 203.09       4.59   0.02   0.83 -96.44
population +Sum.of.area_FM3_17                                   4 203.63       5.12   0.02   0.85 -96.70
sqkmtotalcrop1km+Sum.of.area_FM3_17                              4 203.68       5.18   0.02   0.86 -96.73
sqkmtotalcrop2km+sqkmwater2km                                    4 203.69       5.18   0.02   0.88 -96.73
sqkmtotalcrop2km+ sqkmwater2km+Sum.of.area_FM3_17                5 203.69       5.18   0.02   0.89 -95.08
sqkmwater2km+population                                          4 204.35       5.85   0.01   0.91 -97.07
sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17                 5 204.57       6.06   0.01   0.92 -95.52
sqkmwater2km+Sum.of.area_FM3_17+population                       5 204.60       6.10   0.01   0.93 -95.54
sqkmtotalcrop1km+sqkmwater1km                                    4 204.76       6.25   0.01   0.93 -97.27
sqkmtotalcrop1km+population                                      4 205.05       6.54   0.01   0.94 -97.41
sqkmwater0.5km+population                                        4 205.06       6.56   0.01   0.95 -97.42
sqkmtotalcrop2km+population                                      4 205.30       6.79   0.01   0.96 -97.54
sqkmwater1km+population                                          4 205.56       7.05   0.01   0.96 -97.67
sqkmtotalcrop1km+ sqkmwater1km+Sum.of.area_FM3_17                5 205.98       7.47   0.00   0.97 -96.22
sqkmwater1km+Sum.of.area_FM3_17+population                       5 206.02       7.52   0.00   0.97 -96.25
sqkmtotalcrop2km+population+Sum.of.area_FM3_17                   5 206.22       7.72   0.00   0.98 -96.35
population +Sum.of.area_FM3_17+sqkmwater0.5km                    5 206.29       7.78   0.00   0.98 -96.38
sqkmwater0.5km+Sum.of.area_FM3_17+population                     5 206.29       7.78   0.00   0.99 -96.38
sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17 6 206.65       8.15   0.00   0.99 -94.70
sqkmtotalcrop1km+population+Sum.of.area_FM3_17                   5 206.88       8.37   0.00   0.99 -96.67
sqkmtotalcrop2km+ sqkmwater2km+population                        5 207.00       8.49   0.00   0.99 -96.73
sqkmtotalcrop2km+ sqkmwater2km+population+Sum.of.area_FM3_17     6 207.39       8.88   0.00   1.00 -95.07
sqkmtotalcrop1km+ sqkmwater1km+population                        5 207.85       9.34   0.00   1.00 -97.16
sqkmtotalcrop1km+ sqkmwater1km+population+Sum.of.area_FM3_17     6 209.65      11.14   0.00   1.00 -96.20

#I need to update Table (S1?) with above, I think S2 was reinfection

summary(mm4)
library(ciTools)
add_ci(landp1, mm4, names = c("lcb", "ucb"))

#this gives us the predicted values of the NB model , along with the confidence bands

#https://stats.idre.ucla.edu/r/dae/negative-binomial-regression/:
#This code gives the 95%CIs around the coefficient (by profiling the likelihood function)
(est <- cbind(Estimate = coef(mm4), confint(mm4)))
                    Estimate       2.5 %     97.5 %
  (Intercept)        -0.7008873 -1.05710048 -0.3399762
sqkmtotalcrop0.5km  0.8694304  0.09738151  1.6561000

#To get incidence rate  (we exponentiate the coefficients.. and confidence intervals!):
exp(est)
                    Estimate     2.5 %    97.5 %
  (Intercept)        0.4961449 0.3474618 0.7117872
  sqkmtotalcrop0.5km 2.3855516 1.1022808 5.2388397

#The percent change in the incident rate of (number of expected counts)
  #of infectedkids_baseline is a 2.4% increase for every unit increase in sqkmtotalcrop0.5km (this predictor is logx+1-transformed?).
#or, the expected count is multiplied by a factor 2.4 for every one unit increase in sqkmtotalcrop0.5km
  
#these incidence rates are analagous to 'odds ratio' 'relative risks' 'incidence ratios' etc.
  #they are exponentiated coefficients.
#https://stats.stackexchange.com/questions/124507/what-to-call-exponentiated-coefficients-from-a-poisson-negative-binomial-regress
#https://stats.stackexchange.com/questions/17006/interpretation-of-incidence-rate-ratios?rq=1

  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  #Note:  At scale 0.5km, sq.km total crop cover is not significant , when a subset of 16 village is used 
  #But field ha from social survey is sig for re-infection and the only predictor selected:


#Re-infection considering all radii (0.5-2km):
library(AICcmodavg) 
#0.5km:
re1=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater0.5km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re2=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re3=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+sqkmwater0.5km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re4=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re5=glm.nb(kids.reinfected.Sh.2017~ sqkmwater0.5km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re6=glm.nb(kids.reinfected.Sh.2017~ sqkmwater0.5km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re7=glm.nb(kids.reinfected.Sh.2017~ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re8=glm.nb(kids.reinfected.Sh.2017~ sqkmwater0.5km+Sum.of.area_FM3_17+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re9=glm.nb(kids.reinfected.Sh.2017~ population +offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re10=glm.nb(kids.reinfected.Sh.2017~ population +Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re11=glm.nb(kids.reinfected.Sh.2017~ population +Sum.of.area_FM3_17+sqkmwater0.5km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re12=glm.nb(kids.reinfected.Sh.2017~ Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)

re13=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re14=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re15=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater0.5km+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re16=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
#1km:
re1.1=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater1km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re3.1=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+sqkmwater1km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re5.1=glm.nb(kids.reinfected.Sh.2017~ sqkmwater1km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re6.1=glm.nb(kids.reinfected.Sh.2017~ sqkmwater1km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re7.1=glm.nb(kids.reinfected.Sh.2017~ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re8.1=glm.nb(kids.reinfected.Sh.2017~ sqkmwater1km+Sum.of.area_FM3_17+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re14.1=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re15.1=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater1km+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
#2km
re1.2=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater2km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re3.2=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+sqkmwater2km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re5.2=glm.nb(kids.reinfected.Sh.2017~ sqkmwater2km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re6.2=glm.nb(kids.reinfected.Sh.2017~ sqkmwater2km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re7.2=glm.nb(kids.reinfected.Sh.2017~ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re8.2=glm.nb(kids.reinfected.Sh.2017~ sqkmwater2km+Sum.of.area_FM3_17+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re14.2=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re15.2=glm.nb(kids.reinfected.Sh.2017~ ha.total.of.referenced.fields+ sqkmwater2km+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)

modelsre<-list(re1,re2,re3,re4,re5,re6,re7,re8,re9,re10,re11,re12,re13,re14,re15,re16,re1.1,re3.1,re5.1,re6.1,re7.1,re8.1,re14.1,re15.1,re1.2,re3.2,re5.2,re6.2,re7.2,re8.2,re14.2,re15.2)
Modnamesre <- c('ha.total.of.referenced.fields+ sqkmwater0.5km+population',
              'ha.total.of.referenced.fields+population',
              'ha.total.of.referenced.fields+sqkmwater0.5km',
              'ha.total.of.referenced.fields',
              'sqkmwater0.5km',
              'sqkmwater0.5km+population',
              'sqkmwater0.5km+Sum.of.area_FM3_17',
              'sqkmwater0.5km+Sum.of.area_FM3_17+population',
              'population',
              'population +Sum.of.area_FM3_17',
              'population +Sum.of.area_FM3_17+sqkmwater0.5km',
              'Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17',
              'sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17',
              'ha.total.of.referenced.fields+sqkmwater1km+population',
              'ha.total.of.referenced.fields+sqkmwater1km',
              'sqkmwater1km',
              'sqkmwater1km+population',
              'sqkmwater1km+Sum.of.area_FM3_17',
              'sqkmwater1km+Sum.of.area_FM3_17+population',
              'ha.total.of.referenced.fields+ sqkmwater1km+Sum.of.area_FM3_17',
              'ha.total.of.referenced.fields+ sqkmwater1km+population+Sum.of.area_FM3_17',
              'ha.total.of.referenced.fields+sqkmwater2km+population',
              'ha.total.of.referenced.fields+sqkmwater2km',
              'sqkmwater2km',
              'sqkmwater2km+population',
              'sqkmwater2km+Sum.of.area_FM3_17',
              'sqkmwater2km+Sum.of.area_FM3_17+population',
              'ha.total.of.referenced.fields+ sqkmwater2km+Sum.of.area_FM3_17',
              'ha.total.of.referenced.fields+ sqkmwater2km+population+Sum.of.area_FM3_17') 
aictab(cand.set = modelsre, modnames = Modnamesre, sort = TRUE)

summary(re2)


#This code gives the 95%CIs around the coefficient (by profiling the likelihood function)
(est <- cbind(Estimate = coef(re2), confint(re2)))
                                  Estimate        2.5 %        97.5 %
  (Intercept)                   -0.6724285520 -1.065708344 -0.2771856921
ha.total.of.referenced.fields  0.0056559630  0.002915615  0.0084411927
population                    -0.0003342312 -0.000625471 -0.0000402986
#To get incidence rate  (we exponentiate the coefficients.. and confidence intervals!):
exp(est)
                                Estimate     2.5 %    97.5 %
(Intercept)                   0.5104674 0.3444838 0.7579137
ha.total.of.referenced.fields 1.0056720 1.0029199 1.0084769
population                    0.9996658 0.9993747 0.9999597







###  Repeat the above baseline and infection post treatment regression with S. mansoni:

   ### Baseline S. masoni:


library(AICcmodavg)
library(MASS)
mansoni1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+ sqkmwater0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni3=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+sqkmwater0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni4=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni5=glm.nb(infectedkids_baseline_mansoni~ sqkmwater0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni6=glm.nb(infectedkids_baseline_mansoni~ sqkmwater0.5km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni7=glm.nb(infectedkids_baseline_mansoni~ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni8=glm.nb(infectedkids_baseline_mansoni~ sqkmwater0.5km+Sum.of.area_FM3_17+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni9=glm.nb(infectedkids_baseline_mansoni~ population +offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni10=glm.nb(infectedkids_baseline_mansoni~ population +Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni11=glm.nb(infectedkids_baseline_mansoni~ population +Sum.of.area_FM3_17+sqkmwater0.5km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni12=glm.nb(infectedkids_baseline_mansoni~ Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mansoni13=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni14=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni15=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni16=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mansoni1.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+ sqkmwater1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni2.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni3.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+sqkmwater1km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni4.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni5.1=glm.nb(infectedkids_baseline_mansoni~ sqkmwater1km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni6.1=glm.nb(infectedkids_baseline_mansoni~ sqkmwater1km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni7.1=glm.nb(infectedkids_baseline_mansoni~ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni8.1=glm.nb(infectedkids_baseline_mansoni~ sqkmwater1km+Sum.of.area_FM3_17+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mansoni13.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni14.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni15.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+ sqkmwater1km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni16.1=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop1km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mansoni1.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+ sqkmwater2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni2.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni3.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+sqkmwater2km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni4.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni5.2=glm.nb(infectedkids_baseline_mansoni~ sqkmwater2km+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni6.2=glm.nb(infectedkids_baseline_mansoni~ sqkmwater2km+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni7.2=glm.nb(infectedkids_baseline_mansoni~ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni8.2=glm.nb(infectedkids_baseline_mansoni~ sqkmwater2km+Sum.of.area_FM3_17+population+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

mansoni13.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni14.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni15.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+ sqkmwater2km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)
mansoni16.2=glm.nb(infectedkids_baseline_mansoni~ sqkmtotalcrop2km+population+Sum.of.area_FM3_17+offset(log(kids_baseline)), na.action=na.omit,data = landp1)

models_man<-list(mansoni1,mansoni2,mansoni3,mansoni4,mansoni5,mansoni6,mansoni7,mansoni8,mansoni9,mansoni10,mansoni11,mansoni12,mansoni13,mansoni14,mansoni15,mansoni16,mansoni1.1,mansoni2.1,mansoni3.1,mansoni4.1,mansoni5.1,mansoni6.1,mansoni7.1,mansoni8.1,mansoni13.1,mansoni14.1,mansoni15.1,mansoni16.1,mansoni1.2,mansoni2.2,mansoni3.2,mansoni4.2,mansoni5.2,mansoni6.2,mansoni7.2,mansoni8.2,mansoni13.2,mansoni14.2,mansoni15.2,mansoni16.2)
Modnames_man <- c('sqkmtotalcrop0.5km+ sqkmwater0.5km+population',
                  'sqkmtotalcrop0.5km+population',
                  'sqkmtotalcrop0.5km+sqkmwater0.5km',
                  'sqkmtotalcrop0.5km',
                  'sqkmwater0.5km',
                  'sqkmwater0.5km+population',
                  'sqkmwater0.5km+Sum.of.area_FM3_17',
                  'sqkmwater0.5km+Sum.of.area_FM3_17+population',
                  'population',
                  'population +Sum.of.area_FM3_17',
                  'population +Sum.of.area_FM3_17+sqkmwater0.5km',
                  'Sum.of.area_FM3_17',
                  'sqkmtotalcrop0.5km+Sum.of.area_FM3_17',
                  'sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17',
                  'sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17',
                  'sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17',
                  'sqkmtotalcrop1km+ sqkmwater1km+population',
                  'sqkmtotalcrop1km+population',
                  'sqkmtotalcrop1km+sqkmwater1km',
                  'sqkmtotalcrop1km',
                  'sqkmwater1km',
                  'sqkmwater1km+population',
                  'sqkmwater1km+Sum.of.area_FM3_17',
                  'sqkmwater1km+Sum.of.area_FM3_17+population',
                  'sqkmtotalcrop1km+Sum.of.area_FM3_17',
                  'sqkmtotalcrop1km+ sqkmwater1km+Sum.of.area_FM3_17',
                  'sqkmtotalcrop1km+ sqkmwater1km+population+Sum.of.area_FM3_17',
                  'sqkmtotalcrop1km+population+Sum.of.area_FM3_17',
                  'sqkmtotalcrop2km+ sqkmwater2km+population',
                  'sqkmtotalcrop2km+population',
                  'sqkmtotalcrop2km+sqkmwater2km',
                  'sqkmtotalcrop2km',
                  'sqkmwater2km',
                  'sqkmwater2km+population',
                  'sqkmwater2km+Sum.of.area_FM3_17',
                  'sqkmwater2km+Sum.of.area_FM3_17+population',
                  'sqkmtotalcrop2km+Sum.of.area_FM3_17',
                  'sqkmtotalcrop2km+ sqkmwater2km+Sum.of.area_FM3_17',
                  'sqkmtotalcrop2km+ sqkmwater2km+population+Sum.of.area_FM3_17',
                  'sqkmtotalcrop2km+population+Sum.of.area_FM3_17') 
aictab(cand.set = models_man, modnames = Modnames_man, sort = TRUE)

summary(mansoni4.2)
Coefficients:
                  Estimate Std. Error z value Pr(>|z|)    
(Intercept)       -2.8181     0.7056  -3.994 6.49e-05 ***
sqkmtotalcrop2km   0.2946     0.1520   1.938   0.0526 .

#marginally not sig at 2km


 ##### Post-treatment mansoni;

#Re-infection considering all radii (0.5-2km):
library(AICcmodavg) 
#0.5km:
re1=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater0.5km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re2=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re3=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+sqkmwater0.5km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re4=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re5=glm.nb(kids.reinfected.Sm.2017~ sqkmwater0.5km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re6=glm.nb(kids.reinfected.Sm.2017~ sqkmwater0.5km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re7=glm.nb(kids.reinfected.Sm.2017~ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re8=glm.nb(kids.reinfected.Sm.2017~ sqkmwater0.5km+Sum.of.area_FM3_17+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re9=glm.nb(kids.reinfected.Sm.2017~ population +offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re10=glm.nb(kids.reinfected.Sm.2017~ population +Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re11=glm.nb(kids.reinfected.Sm.2017~ population +Sum.of.area_FM3_17+sqkmwater0.5km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re12=glm.nb(kids.reinfected.Sm.2017~ Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)

re13=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re14=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater0.5km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re15=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater0.5km+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re16=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
#1km:
re1.1=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater1km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re3.1=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+sqkmwater1km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re5.1=glm.nb(kids.reinfected.Sm.2017~ sqkmwater1km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re6.1=glm.nb(kids.reinfected.Sm.2017~ sqkmwater1km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re7.1=glm.nb(kids.reinfected.Sm.2017~ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re8.1=glm.nb(kids.reinfected.Sm.2017~ sqkmwater1km+Sum.of.area_FM3_17+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re14.1=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater1km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re15.1=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater1km+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
#2km
re1.2=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater2km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re3.2=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+sqkmwater2km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re5.2=glm.nb(kids.reinfected.Sm.2017~ sqkmwater2km+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re6.2=glm.nb(kids.reinfected.Sm.2017~ sqkmwater2km+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re7.2=glm.nb(kids.reinfected.Sm.2017~ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re8.2=glm.nb(kids.reinfected.Sm.2017~ sqkmwater2km+Sum.of.area_FM3_17+population+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re14.2=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater2km+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)
re15.2=glm.nb(kids.reinfected.Sm.2017~ ha.total.of.referenced.fields+ sqkmwater2km+population+Sum.of.area_FM3_17+offset(log(kids.tested.reinfection.Sh.2017)), na.action=na.omit,data = landp1)

modelsre<-list(re1,re2,re3,re4,re5,re6,re7,re8,re9,re10,re11,re12,re13,re14,re15,re16,re1.1,re3.1,re5.1,re6.1,re7.1,re8.1,re14.1,re15.1,re1.2,re3.2,re5.2,re6.2,re7.2,re8.2,re14.2,re15.2)
Modnamesre <- c('ha.total.of.referenced.fields+ sqkmwater0.5km+population',
                'ha.total.of.referenced.fields+population',
                'ha.total.of.referenced.fields+sqkmwater0.5km',
                'ha.total.of.referenced.fields',
                'sqkmwater0.5km',
                'sqkmwater0.5km+population',
                'sqkmwater0.5km+Sum.of.area_FM3_17',
                'sqkmwater0.5km+Sum.of.area_FM3_17+population',
                'population',
                'population +Sum.of.area_FM3_17',
                'population +Sum.of.area_FM3_17+sqkmwater0.5km',
                'Sum.of.area_FM3_17',
                'sqkmtotalcrop0.5km+Sum.of.area_FM3_17',
                'sqkmtotalcrop0.5km+ sqkmwater0.5km+Sum.of.area_FM3_17',
                'sqkmtotalcrop0.5km+ sqkmwater0.5km+population+Sum.of.area_FM3_17',
                'sqkmtotalcrop0.5km+population+Sum.of.area_FM3_17',
                'ha.total.of.referenced.fields+sqkmwater1km+population',
                'ha.total.of.referenced.fields+sqkmwater1km',
                'sqkmwater1km',
                'sqkmwater1km+population',
                'sqkmwater1km+Sum.of.area_FM3_17',
                'sqkmwater1km+Sum.of.area_FM3_17+population',
                'ha.total.of.referenced.fields+ sqkmwater1km+Sum.of.area_FM3_17',
                'ha.total.of.referenced.fields+ sqkmwater1km+population+Sum.of.area_FM3_17',
                'ha.total.of.referenced.fields+sqkmwater2km+population',
                'ha.total.of.referenced.fields+sqkmwater2km',
                'sqkmwater2km',
                'sqkmwater2km+population',
                'sqkmwater2km+Sum.of.area_FM3_17',
                'sqkmwater2km+Sum.of.area_FM3_17+population',
                'ha.total.of.referenced.fields+ sqkmwater2km+Sum.of.area_FM3_17',
                'ha.total.of.referenced.fields+ sqkmwater2km+population+Sum.of.area_FM3_17') 
aictab(cand.set = modelsre, modnames = Modnamesre, sort = TRUE)

summary(re12)


#This code gives the 95%CIs around the coefficient (by profiling the likelihood function)
(est <- cbind(Estimate = coef(re2), confint(re2)))
Estimate        2.5 %        97.5 %
  (Intercept)                   -0.6724285520 -1.065708344 -0.2771856921
ha.total.of.referenced.fields  0.0056559630  0.002915615  0.0084411927
population                    -0.0003342312 -0.000625471 -0.0000402986
#To get incidence rate  (we exponentiate the coefficients.. and confidence intervals!):
exp(est)
Estimate     2.5 %    97.5 %
  (Intercept)                   0.5104674 0.3444838 0.7579137
ha.total.of.referenced.fields 1.0056720 1.0029199 1.0084769
population                    0.9996658 0.9993747 0.9999597





##################################################
#PATH MODEL FOR HUMAN INFECTION

#################################################
#HUMAN INFECTION PSEM:

#Examine for significant paths from ag->veg->snails->prev
#We must subset to single Fm per human infection round because only one round for 7 USF villages...
#Analysis uses only summer data : chose FM1,4,17 


library(piecewiseSEM)
library(nlme)
library(lme4)

# Load dataset that excludes only response variables from site-time points that might be vulnerable to prawn or veg removal impacts:
FM1_4_17_2=read.csv("C:/Users/Chris/Desktop/agri schisto ms/EHP submission/psem_data_1_13_fixed_exclusion.csv")
#Scale predictors:
FM1_4_17_2$prop=FM1_4_17_2$infected.kids/FM1_4_17_2$kids.tested
FM1_4_17_2$scalefloating=scale(FM1_4_17_2$Sum.of.floating)
FM1_4_17_2$scalesqkmtotalcrop0.5km=scale(FM1_4_17_2$sqkmtotalcrop0.5km)
FM1_4_17_2$scaletotalvegmass=scale(FM1_4_17_2$Sum.of.totalvegsum)
FM1_4_17_2$scaletotalbulinus=scale(FM1_4_17_2$Sum.of.totalbulinus)
FM1_4_17_2$scalelogtotalbulinus=scale(log(FM1_4_17_2$Sum.of.totalbulinus+1))
FM1_4_17_2$scalelogtotalbiom=scale(log(FM1_4_17_2$sum_of_biomphalaria+1))
FM1_4_17_2$scaleCount.of.Microhabitat.Other=scale(FM1_4_17_2$Count.of.Microhabitat.Other)
FM1_4_17_2$logNpoint=log(FM1_4_17_2$Count.of.Microhabitat.Other+1)
FM1_4_17_2$scalelogCount.of.Microhabitat.Other=scale(FM1_4_17_2$logNpoint)
FM1_4_17_2$scalelogvegmass=scale(log(FM1_4_17_2$Sum.of.totalvegsum+1))
FM1_4_17_2$scalevillagepop=scale(FM1_4_17_2$population)
FM1_4_17_2$scalesexratio=scale(FM1_4_17_2$sexratio)
FM1_4_17_2$scaleaverageclass=scale(FM1_4_17_2$avgclass)
FM1_4_17_2$scalehafert=scale(FM1_4_17_2$Totalfertilizer)



#try initial global 
psem_finale22 = psem(
  lme(scalefloating ~ scalesqkmtotalcrop0.5km+scalehafert, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogCount.of.Microhabitat.Other ~ scalefloating, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogvegmass ~ scalelogCount.of.Microhabitat.Other+scalehafert, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogtotalbulinus ~ scalelogvegmass, random = ~1|villages,na.action=na.omit,data = FM1_4_17_2),
  glmer(prop~scalevillagepop+scalelogtotalbulinus + scalefloating+scalesqkmtotalcrop0.5km+(1|villages),family="binomial",weights=kids.tested,na.action=na.omit,data=FM1_4_17_2))
summary(psem_finale22)
#runs, thus need to use this to update the global model tables. Note village pop is first predictor to drop out, simplifying the necessary updates
AIC      BIC
 90.070   121.17

#drop villagepop, total fert ha...
psem_finale = psem(
  lme(scalefloating ~ scalesqkmtotalcrop0.5km, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogCount.of.Microhabitat.Other ~ scalefloating, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogvegmass ~ scalelogCount.of.Microhabitat.Other, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogtotalbulinus ~ scalelogvegmass, random = ~1|villages,na.action=na.omit,data = FM1_4_17_2),
  glmer(prop~scalelogtotalbulinus + scalefloating+scalesqkmtotalcrop0.5km+(1|villages),family="binomial",weights=kids.tested,na.action=na.omit,data=FM1_4_17_2))
summary(psem_finale222)
AIC      BIC
67.157   94.37
---
  Tests of directed separation:
  
  Independ.Claim Estimate Std.Error DF Crit.Value P.Value   
scalelogCount.of.Microhabitat.Other   ~  scalesqkmtotalcrop0.5km + ...  -0.2487    0.2511 14    -0.9905  0.3387   
scalelogvegmass                       ~  scalesqkmtotalcrop0.5km + ...  -0.2239    0.1765 14    -1.2685  0.2253   
scalelogtotalbulinus                  ~  scalesqkmtotalcrop0.5km + ...  -0.3916    0.1320 21    -2.9656  0.0074 **
scalelogvegmass                                 ~  scalefloating + ...   0.3225    0.2006 10     1.6074  0.1391   
scalelogtotalbulinus                            ~  scalefloating + ...   0.2250    0.1689  6     1.3321  0.2312   
prop                      ~  scalelogCount.of.Microhabitat.Other + ...   0.2749    0.2792 NA     0.9847  0.3248   
scalelogtotalbulinus      ~  scalelogCount.of.Microhabitat.Other + ...   0.1170    0.2172  5     0.5386  0.6132   
scalelogvegmass                                          ~  prop + ...   0.0545    0.7787  1     0.0700  0.9555   
Global goodness-of-fit:
  Fisher's C = 25.157 with P-value = 0.067 and on 16 degrees of freedom
---
  Coefficients:
  
Response                           Predictor Estimate                Std.Error DF Crit.Value P.Value Std.Estimate   
scalefloating                       scalesqkmtotalcrop0.5km   0.5551    0.1739 21     3.1925  0.0044       0.5711 **
scalelogCount.of.Microhabitat.Other           scalefloating   0.3750    0.1857 11     2.0192  0.0685       0.3561   
scalelogvegmass         scalelogCount.of.Microhabitat.Other   0.4000    0.1584 15     2.5259  0.0233       0.4000  *
scalelogtotalbulinus                        scalelogvegmass   0.6282    0.1467 10     4.2832  0.0016       0.6342 **
prop                                   scalelogtotalbulinus   0.3626    0.2063 27     1.7573  0.0789           NA   
prop                                          scalefloating   0.4222    0.2424 27     1.7417  0.0816           NA   
prop                                scalesqkmtotalcrop0.5km   0.9927    0.3069 27     3.2350  0.0012           NA **
  
  Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05

  Individual R-squared:
                  Response method Marginal Conditional
                        scalefloating   none     0.31        0.85
  scalelogCount.of.Microhabitat.Other   none     0.14        0.80
                      scalelogvegmass   none     0.19        0.68
                  scalelogtotalbulinus  none     0.40        0.72
                                  prop  delta     0.22        0.37  

#switch to one-tailed p-value given strog apriori hypo supported by literature
#then  address individual-level traits in child-level
#used above results to update Fig. 4; Table S8, S9, and S14 using psem_finale above 


#Path model for S. mansoni

FM1_4_17_2$prop_m=FM1_4_17_2$infected.kids.mansoni/FM1_4_17_2$kids.tested

#try initial global 
psem_mansoni = psem(
  lme(scalefloating ~ scalesqkmtotalcrop0.5km+scalehafert, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogCount.of.Microhabitat.Other ~ scalefloating, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogvegmass ~ scalelogCount.of.Microhabitat.Other+scalehafert, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogtotalbiom ~ scalelogvegmass, random = ~1|villages,na.action=na.omit,data = FM1_4_17_2),
  glmer(prop_m~scalevillagepop+scalelogtotalbiom + scalefloating+scalesqkmtotalcrop0.5km+(1|villages),family="binomial",weights=kids.tested,na.action=na.omit,data=FM1_4_17_2))
summary(psem_mansoni)

#drop nonsig paths from each response:
psem_mansoni2 = psem(
  lme(scalefloating ~ scalesqkmtotalcrop0.5km, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogvegmass ~ scalelogCount.of.Microhabitat.Other, random = ~ 1|villages,na.action=na.omit,data = FM1_4_17_2),
  lme(scalelogtotalbiom ~ scalelogvegmass, random = ~1|villages,na.action=na.omit,data = FM1_4_17_2),
  glmer(prop_m~scalevillagepop + scalefloating+scalesqkmtotalcrop0.5km+(1|villages),family="binomial",weights=kids.tested,na.action=na.omit,data=FM1_4_17_2))
summary(psem_mansoni2)
#Why is the S. mansoni prop negative to floating? I think the massive spike at Gankette is big part - this site had new
#area of open water that we did not account for (new water access area where we would miss vegetation).

FM1_4_17_2$villages
#lets drop gankette, row 11:

nogankette=FM1_4_17_2[-c(11), ] 
nogankette$villages

#try initial global 
psem_mansoni3 = psem(
  lme(scalefloating ~ scalesqkmtotalcrop0.5km+scalehafert, random = ~ 1|villages,na.action=na.omit,data = nogankette),
  lme(scalelogCount.of.Microhabitat.Other ~ scalefloating, random = ~ 1|villages,na.action=na.omit,data = nogankette),
  lme(scalelogvegmass ~ scalelogCount.of.Microhabitat.Other+scalehafert, random = ~ 1|villages,na.action=na.omit,data = nogankette),
  lme(scalelogtotalbiom ~ scalelogvegmass, random = ~1|villages,na.action=na.omit,data = nogankette),
  glmer(prop_m~scalevillagepop+scalelogtotalbiom + scalefloating+scalesqkmtotalcrop0.5km+(1|villages),family="binomial",weights=kids.tested,na.action=na.omit,data=nogankette))
summary(psem_mansoni3)

#floating is still a sig - predictor of S. mansoni prev.  ????
#note this sig + path in the d-sep tests:prop_m  ~  scalelogCount.of.Microhabitat.Other
psem_mansoni3.1 = psem(
  lme(scalefloating ~ scalesqkmtotalcrop0.5km+scalehafert, random = ~ 1|villages,na.action=na.omit,data = nogankette),
  lme(scalelogCount.of.Microhabitat.Other ~ scalefloating, random = ~ 1|villages,na.action=na.omit,data = nogankette),
  lme(scalelogvegmass ~ scalelogCount.of.Microhabitat.Other+scalehafert, random = ~ 1|villages,na.action=na.omit,data = nogankette),
  lme(scalelogtotalbiom ~ scalelogvegmass, random = ~1|villages,na.action=na.omit,data = nogankette),
  glmer(prop_m~scalevillagepop+scalelogtotalbiom + scalefloating+scalesqkmtotalcrop0.5km+(1|villages),family="binomial",weights=kids.tested,na.action=na.omit,data=nogankette),
  prop_m  %~~%   scalelogCount.of.Microhabitat.Other)
summary(psem_mansoni3.1)

#Adding correlated error does not change that floating is sig - predictor of prop_m
#what if instead we add the pathway to the model?



###################
#Child-level model:
###################

#start with same human data as in the path model, with snails and veg corresponding to FM1 and FM4 for 2017 and 2018, respectively:
dataset3s=read.csv("C:/Users/Chris/Desktop/agri schisto ms/EHP submission/human_data_per_child_2017_2018.csv")
names(dataset3s)
#Scale predictors:
dataset3s$scalefloating=scale(dataset3s$floating)
dataset3s$scalesqkmtotalcrop0.5km=scale(dataset3s$sqkmtotalcrop0.5km)
dataset3s$scaletotalvegmass=scale(dataset3s$vegmass)
dataset3s$scaletotalbulinus=scale(dataset3s$totalbulinus)
dataset3s$scalelogtotalbulinus=scale(log(dataset3s$totalbulinus+1))
dataset3s$scalepopulation=scale(log(dataset3s$Pop))
dataset3s$scaleaccessarea=scale(dataset3s$accessarea)
dataset3s$sex2=factor(dataset3s$sex2)
dataset3s$class=factor(dataset3s$Class)
#dataset3s$manipulation=factor(dataset3s$manipulation)

#need to exclude only the timepoints with prawns and veg removal:
dataset5s=dataset3s[dataset3s$exclude_timepoint2 == "0", ]
dataset5s$exclude_timepoint <- dataset5s$exclude_timepoint[ , drop=TRUE]
#Scale predictors:
dataset5s$scalefloating=scale(dataset5s$floating)
dataset5s$scalesqkmtotalcrop0.5km=scale(dataset5s$sqkmtotalcrop0.5km)
dataset5s$scaletotalvegmass=scale(dataset5s$vegmass)
dataset5s$scaletotalbulinus=scale(dataset5s$totalbulinus)
dataset5s$scalelogtotalbulinus=scale(log(dataset5s$totalbulinus+1))
dataset5s$scalepopulation=scale(log(dataset5s$Pop))
dataset5s$scaleaccessarea=scale(dataset5s$accessarea)
dataset5s$sex2=factor(dataset5s$sex2)
dataset5s$class=factor(dataset5s$Class)

#Global model:
library(lme4)
childmodel_lake11=glmer(Sh~ scaleaccessarea+sex2+Class+scalepopulation+scalefloating+scalesqkmtotalcrop0.5km+scalelogtotalbulinus+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_lake11)
#Fixed effects:
#                           Estimate Std. Error z value Pr(>|z|)    
#   (Intercept)              0.93448    0.28217   3.312 0.000927 ***
##  scaleaccessarea          0.13716    0.48049   0.285 0.775289    
#   sex21                    0.36463    0.12023   3.033 0.002422 ** 
#   Class                   -0.02713    0.06609  -0.411 0.681387    
#   scalepopulation         -0.42953    0.21303  -2.016 0.043764 *  
##  scalefloating            0.57334    0.38288   1.497 0.134278    
#   scalesqkmtotalcrop0.5km  1.01248    0.35747   2.832 0.004620 ** 
#   scalelogtotalbulinus     0.48730    0.21432   2.274 0.022984 *

#drop access area:
childmodel_lake12=glmer(Sh~ sex2+Class+scalepopulation+scalefloating+scalesqkmtotalcrop0.5km+scalelogtotalbulinus+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_lake12)
#drop non-significant terms to final model:
childmodel_lake13=glmer(Sh~ sex2+scalepopulation+scalefloating+scalesqkmtotalcrop0.5km+scalelogtotalbulinus+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_lake13)
Fixed effects:
  Estimate Std. Error z value Pr(>|z|)    
(Intercept)               0.8748     0.2453   3.566 0.000362 ***
  sex21                     0.3619     0.1199   3.019 0.002534 ** 
  scalepopulation          -0.4471     0.1992  -2.245 0.024771 *  
  scalefloating             0.6506     0.2788   2.334 0.019608 *  
  scalesqkmtotalcrop0.5km   1.0448     0.3349   3.120 0.001808 ** 
  scalelogtotalbulinus      0.4811     0.2134   2.255 0.024136 * 


#try for S. mansoni per reviewer:
childmodel_Sm=glmer(Sm~ scaleaccessarea+sex2+Class+scalepopulation+scalefloating+scalesqkmtotalcrop0.5km+scalelogtotalbulinus+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm)
Number of obs: 1728, groups:  ID:School, 1289; School, 15

Fixed effects:
                        Estimate Std. Error z value Pr(>|z|)    
(Intercept)             -2.16100    0.38998  -5.541    3e-08 ***
scaleaccessarea         -0.41597    0.61381  -0.678  0.49797    
sex21                    0.53420    0.14844   3.599  0.00032 ***
Class                   -0.06578    0.07496  -0.878  0.38020    
scalepopulation          0.08839    0.33160   0.267  0.78982    
scalefloating            0.22281    0.42004   0.530  0.59580    
scalesqkmtotalcrop0.5km  0.18063    0.49207   0.367  0.71356    
scalelogtotalbulinus     0.06944    0.29520   0.235  0.81402 

#drop total bulinus
childmodel_Sm2=glmer(Sm~ scaleaccessarea+sex2+Class+scalepopulation+scalefloating+scalesqkmtotalcrop0.5km+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm2)

Fixed effects:
                        Estimate Std. Error z value Pr(>|z|)    
(Intercept)             -2.16330    0.38920  -5.558 2.72e-08 ***
scaleaccessarea         -0.42025    0.61082  -0.688 0.491441    
sex21                    0.53469    0.14843   3.602 0.000315 ***
Class                   -0.06504    0.07490  -0.868 0.385187    
scalepopulation          0.09731    0.32852   0.296 0.767072    
scalefloating            0.24562    0.40517   0.606 0.544366    
scalesqkmtotalcrop0.5km  0.13433    0.45188   0.297 0.766260

#drop population
childmodel_Sm3=glmer(Sm~ scaleaccessarea+sex2+Class+scalefloating+scalesqkmtotalcrop0.5km+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm3)

Estimate Std. Error z value Pr(>|z|)    
(Intercept)             -2.15551    0.38657  -5.576 2.46e-08 ***
scaleaccessarea         -0.45006    0.60138  -0.748 0.454236    
sex21                    0.53540    0.14840   3.608 0.000309 ***
Class                   -0.06580    0.07483  -0.879 0.379270    
scalefloating            0.27674    0.39281   0.705 0.481113    
scalesqkmtotalcrop0.5km  0.11621    0.44520   0.261 0.794077 

#drop crops
childmodel_Sm4=glmer(Sm~ scaleaccessarea+sex2+Class+scalefloating+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm4)
Estimate Std. Error z value Pr(>|z|)    
(Intercept)     -2.14376    0.38412  -5.581 2.39e-08 ***
scaleaccessarea -0.36622    0.51015  -0.718  0.47284    
sex21            0.53515    0.14839   3.606  0.00031 ***
Class           -0.06504    0.07478  -0.870  0.38443    
scalefloating    0.26648    0.39073   0.682  0.49524 

#drop floating
childmodel_Sm5=glmer(Sm~ scaleaccessarea+sex2+Class+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm5)
Estimate Std. Error z value Pr(>|z|)    
(Intercept)     -2.12364    0.38147  -5.567 2.59e-08 ***
scaleaccessarea -0.10820    0.33757  -0.321 0.748573    
sex21            0.53459    0.14837   3.603 0.000315 ***
Class           -0.06780    0.07467  -0.908 0.363918 

#drop access area:
childmodel_Sm6=glmer(Sm~ sex2+Class+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm6)
#drop class
childmodel_Sm7=glmer(Sm~ sex2+(1|School/ID), family=binomial, data=dataset5s,na.action=na.omit,control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000)))
summary(childmodel_Sm7)
Fixed effects:
            Estimate Std. Error z value Pr(>|z|)    
(Intercept)  -2.1688     0.3245  -6.684 2.32e-11 ***
sex21         0.3983     0.1336   2.981  0.00287 **

AIC(childmodel_Sm,childmodel_Sm2,childmodel_Sm3,childmodel_Sm4,childmodel_Sm5,childmodel_Sm6)
#not fit to same # observations so AIC jumps up for Sm6...

              df      AIC
childmodel_Sm  10 1392.456
childmodel_Sm2  9 1390.509
childmodel_Sm3  8 1388.598
childmodel_Sm4  7 1386.666
childmodel_Sm5  6 1385.093
childmodel_Sm6  5 1701.175





  


#Create a figure showing agriculture at lakes versus rivers:
landp1 <- read.csv("C://Users/Chris/Desktop/latest agri edits/landuse_stanford_and_our7village_weightedmeans_1_13.csv")
library(plyr)
report1=ddply(landp1,c("waterway"),summarize,
               N=length(sqkmtotalcrop0.5km),
               avg=mean(sqkmtotalcrop0.5km,na.rm=TRUE),
               sd=sd(sqkmtotalcrop0.5km,na.rm=TRUE),
               se=sd/sqrt(N),
               ucl=avg+1.98*se,
               lcl=avg-1.98*se)
#Plot of sqkmtotalcrop0.5km  with 95%CI:
plot1 <- ggplot(data=report1, aes(x=waterway, y=avg))+
  ggtitle("")+ ylab("Avg. total crop cover (sq. km) in 0.5km w/ 95% CI")+ xlab("")+
  geom_point(position=position_dodge(w=0.1), size=3.4)+  
  geom_errorbar(aes(ymax=ucl, ymin=lcl), width=0.4, position=position_dodge(w=0.1))+
  theme_bw() +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank()) +theme(axis.text=element_text(size=16), axis.title=element_text(size=16,face="bold"))
setwd("C:/Users/Chris/Desktop/")
tiff(file="plotlakeriver.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
plot1
dev.off()
#try the same but for ha total of referenced fields
report1.2=ddply(landp1,c("waterway"),summarize,
               N=length(ha.total.of.referenced.fields),
               avg=mean(ha.total.of.referenced.fields,na.rm=TRUE),
               sd=sd(ha.total.of.referenced.fields,na.rm=TRUE),
               se=sd/sqrt(N),
               ucl=avg+1.98*se,
               lcl=avg-1.98*se)
#Plot of ha.total.of.referenced.fields  with 95%CI:
plot1.2 <- ggplot(data=report1.2, aes(x=waterway, y=avg))+
  ggtitle("")+ ylab("Avg. total crop cover (ha) in 0.5km w/ 95% CI")+ xlab("")+
  geom_point(position=position_dodge(w=0.1), size=3.4)+  
  geom_errorbar(aes(ymax=ucl, ymin=lcl), width=0.4, position=position_dodge(w=0.1))+
  theme_bw() +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank()) +theme(axis.text=element_text(size=16),
                                                                          axis.title=element_text(size=18,face="bold"))
plot1.2

#Similar trend but 7 less villages = not significant.

setwd("C:/Users/Chris/Desktop/")
tiff(file="plotlakeriver_ha.tif",height=4800,width=5200,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
plot1.2
dev.off()



#########################
#snail methods comparison:
#########################

#Fig S4

snailsdat=read.csv("C:/Users/Chris/Desktop/latest agri edits/snail_points_USF_Stanford.csv")
library(plyr)
bul1 =ddply(snailsdat,c("id"),summarize,
            N=length(bulinus),
            avg=mean(bulinus,na.rm=TRUE),
            sd=sd(bulinus,na.rm=TRUE),
            se=sd/sqrt(N),
            ucl=avg+1.98*se,
            lcl=avg-1.98*se)
library(ggplot2)
plotbul <- ggplot(data=bul1, aes(x=id, y=avg))+
  ggtitle("")+ ylab("Avg. Bul. snails w/ 95% CI")+ xlab("")+
  geom_point(position=position_dodge(w=0.1), size=3.4)+  
  geom_errorbar(aes(ymax=ucl, ymin=lcl), width=0.4, position=position_dodge(w=0.1))+
  theme_bw() +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank()) 
plotbul
#no sig diff
biom1 =ddply(snailsdat,c("id"),summarize,
             N=length(Biomphalaria),
             avg=mean(Biomphalaria,na.rm=TRUE),
             sd=sd(Biomphalaria,na.rm=TRUE),
             se=sd/sqrt(N),
             ucl=avg+1.98*se,
             lcl=avg-1.98*se)
plotbiom <- ggplot(data=biom1, aes(x=id, y=avg))+
  ggtitle("")+ ylab("Avg. Biom. snails w/ 95% CI")+ xlab("")+
  geom_point(position=position_dodge(w=0.1), size=3.4)+  
  geom_errorbar(aes(ymax=ucl, ymin=lcl), width=0.4, position=position_dodge(w=0.1))+
  theme_bw() +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank()) 
plotbiom
#no sig diff

library(gridExtra)
setwd("C:/Users/Chris/Desktop/")
tiff(file="snailmethods.tif",height=2700,width=5000,units="px",res=800,compression="lzw")
par(mar=c(5,6,4,1)+.1)
grid.arrange(plotbul,plotbiom,ncol=2)
dev.off()

#would visreg of models be better to plot?
#ZINB were favored by AIC over NB
nbulc = glmmTMB(round(bulinus) ~ id+Mass  + (1|UniqueSiteQuad), data=snailsdat, na.action=na.omit, family=nbinom2, ziformula=~nomass)
Anova(nbulc)
Response: round(bulinus)
Chisq Df Pr(>Chisq)
id   1.4666  1     0.2259
Mass 0.3254  1     0.5684

#re-run without zero inflation:
nbulc2 = glmmTMB(round(bulinus) ~ id+Mass+(1|UniqueSiteQuad), data=snailsdat, na.action=na.omit, family=nbinom2)
Anova(nbulc2)
Response: round(bulinus)
Chisq Df Pr(>Chisq)    
id    0.9175  1     0.3381    
Mass 21.8595  1  2.934e-06 ***  
  
  visreg(nbulc2,"id",scale="response")

nbulc3 = glmmTMB(round(bulinus) ~ id+(1|Site.ID/UniqueSiteQuad), data=snailsdat, na.action=na.omit, family=nbinom2)
Anova(nbulc3)
Analysis of Deviance Table (Type II Wald chisquare tests)

Response: round(bulinus)
Chisq Df Pr(>Chisq)
id 0.7612  1      0.383

nbiom1 = glmmTMB(round(Biomphalaria) ~ id+Mass  + (1|UniqueSiteQuad), data=snailsdat, na.action=na.omit, family=nbinom2)
Anova(nbiom1)
Response: round(bulinus)
Chisq Df Pr(>Chisq)    
id    0.9175  1     0.3381    
Mass 21.8595  1  2.934e-06 ***
  
  nbiom = glmmTMB(round(Biomphalaria) ~ id+Mass  + (1|UniqueSiteQuad), data=snailsdat, na.action=na.omit, family=nbinom2, ziformula=~nomass)
Anova(nbiom)

Response: round(Biomphalaria)
Chisq Df Pr(>Chisq)  
id   0.3383  1    0.56083  
Mass 4.2217  1    0.03991 *
  ---
  Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
visreg(nbiom)#doesn't like ZINB models
visreg(nbiom1,"id",scale="response")





